namespace elm { 
inline ::efl::eolian::return_traits<int>::type Radio::state_value_get() const
{
   int __return_value =  ::elm_obj_radio_state_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Radio::state_value_set( ::efl::eolian::in_traits<int>::type value) const
{
    ::elm_obj_radio_state_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(value));
}
inline ::efl::eolian::return_traits<int>::type Radio::value_get() const
{
   int __return_value =  ::elm_obj_radio_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Radio::value_set( ::efl::eolian::in_traits<int>::type value) const
{
    ::elm_obj_radio_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(value));
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Radio::selected_object_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_radio_selected_object_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Radio::group_add( ::efl::eolian::in_traits< ::elm::Radio>::type group) const
{
    ::elm_obj_radio_group_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Radio*,  ::efl::eolian::in_traits< ::elm::Radio>::type>(group));
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<int>::type Radio::state_value_get() const
{
   int __return_value =  ::elm_obj_radio_state_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Radio::state_value_set( ::efl::eolian::in_traits<int>::type value) const
{
    ::elm_obj_radio_state_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(value));
}
inline ::efl::eolian::return_traits<int>::type Radio::value_get() const
{
   int __return_value =  ::elm_obj_radio_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Radio::value_set( ::efl::eolian::in_traits<int>::type value) const
{
    ::elm_obj_radio_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(value));
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Radio::selected_object_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_radio_selected_object_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Radio::group_add( ::efl::eolian::in_traits< ::elm::Radio>::type group) const
{
    ::elm_obj_radio_group_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Radio*,  ::efl::eolian::in_traits< ::elm::Radio>::type>(group));
}
inline elm::Radio::operator ::elm::Radio() const { return *static_cast< ::elm::Radio const*>(static_cast<void const*>(this)); }
inline elm::Radio::operator ::elm::Radio&() { return *static_cast< ::elm::Radio*>(static_cast<void*>(this)); }
inline elm::Radio::operator ::elm::Radio const&() const { return *static_cast< ::elm::Radio const*>(static_cast<void const*>(this)); }
} }

